@@ -1436,7 +1436,7 @@ def cli(
                                     report_obj.poster_four = (
                                         str(df03.iloc[3]["unique_values"])
                                         + ", "
-                                        + df03.iloc[3]["counts"]
+                                        + str(df03.iloc[3]["counts"])
                                         + " messages"
                                     )
                                     report_obj.poster_four = (
