@@ -205,8 +205,8 @@ def print_shell(type, obj):
 
     if type == "channel_recap" or type == "group_recap":
 
-        d_wrapper = generate_textwrap("Description")
-        td_wrapper = generate_textwrap("Translated Description")
+        d_wrapper = generate_textwrap("Description:")
+        td_wrapper = generate_textwrap("Translated Description:")
 
         color_print_green("  ┬  Chat details", "")
         color_print_green("  ├  Title: ", str(obj.title))
@@ -240,7 +240,7 @@ def print_shell(type, obj):
                 "  ├  Memberlist saved to: ", obj.memberlist_filename
             )
         color_print_green(
-            "  └  ", d_wrapper.fill(obj.group_status)
+            "  └  Restrictions: ", (str(obj.group_status))
         )
 
     if type == "group_stat":
